@@ -6,7 +6,7 @@ import pkg_resources
 
 from entropylab.dashboard import serve_dashboard
 from entropylab.logger import logger
-from entropylab.results_backend.sqlalchemy import init_db, upgrade_db
+from entropylab.pipeline.results_backend.sqlalchemy import init_db, upgrade_db
 
 
 # Decorator for friendly error messages
