@@ -26,11 +26,14 @@ from entropylab.logger import logger
 from entropylab.pipeline.api.errors import EntropyError
 from entropylab.pipeline.api.param_store import ParamStore, MergeStrategy, Param
 
+CURRENT_VERSION = 0.2
+
 INFO_DOC_ID = 1
 INFO_TABLE = "info"
 TEMP_DOC_ID = 1
 TEMP_TABLE = "temp"
 VERSION_KEY = "version"
+REVISION_KEY = "revision"
 
 
 class Metadata:
@@ -107,20 +110,27 @@ class InProcessParamStore(ParamStore):
             self.__is_in_memory_mode = True
             self.__db = TinyDB(storage=MemoryStorage)
             self.__filelock = contextlib.nullcontext()
+            with self.__filelock:
+                _set_version(self.__db, CURRENT_VERSION)
         else:
             self.__is_in_memory_mode = False
-            if isinstance(path, Path):
-                path = str(path)
+            path = str(path)
+            is_new = not os.path.isfile(path)
             if not os.path.isfile(path):
                 logger.debug(
                     f"Could not find a ParamStore JSON file at '{path}'. "
                     f"A new, empty, file will be created."
                 )
+                is_new = True
             self.__db = TinyDB(path, storage=JSONPickleStorage)
             Table.default_query_cache_capacity = 0
             self.__filelock = FileLock(path + ".lock")
             with self.__filelock:
-                self.checkout()
+                if is_new:
+                    logger.debug(f"Creating new ParamStore JSON file at '{path}'")
+                    _set_version(self.__db, CURRENT_VERSION)
+                else:
+                    self.checkout()
         if theirs is not None:
             self.merge(theirs, merge_strategy)
 
@@ -629,7 +639,40 @@ def _extract_param_values_in_place(d: Dict):
 """ Migrations """
 
 
-def migrate_param_store_0_1_to_0_2(path: str) -> None:
+def fix_param_qualified_name(path: str | Path, revision: str):
+    """
+    Backup and fix the fully qualified names of Param in an InProcessParamStore JSON
+    file.
+
+    :param path: path to an existing JSON TinyDB file containing params.
+    """
+    if not os.path.isfile(path):
+        return
+    OLD_NAME = "entropylab.api.in_process_param_store.Param"
+    NEW_NAME = "entropylab.pipeline.api.param_store.Param"
+    path = str(path)
+    backup_path = _backup_file(path, revision)
+    # TODO: Support locking
+    with TinyDB(backup_path) as old_db:
+        old_commits = old_db.all()
+        old_temp = old_db.table(TEMP_TABLE).get(doc_id=TEMP_DOC_ID)
+        old_info = old_db.table(INFO_TABLE).get(doc_id=INFO_DOC_ID)
+    with TinyDB(path) as new_db:
+        for old_commit in old_commits:
+            new_commit = copy.deepcopy(old_commit)
+            for param in new_commit["params"].values():
+                if "py/object" in param and param["py/object"] == OLD_NAME:
+                    param["py/object"] = NEW_NAME
+            new_db.insert(new_commit)
+        if old_temp:
+            new_temp = copy.deepcopy(old_temp)
+            new_db.table(TEMP_TABLE).insert(new_temp)
+        if old_info:
+            new_info = copy.deepcopy(old_info)
+            new_db.table(INFO_TABLE).insert(new_info)
+
+
+def migrate_param_store_0_1_to_0_2(path: str | Path, revision: str) -> None:
     """
     Backup and migrate an InProcessParamStore JSON file from storing values to storing
     Params containing the values. Preserves commits, timestamps and ids.
@@ -639,8 +682,10 @@ def migrate_param_store_0_1_to_0_2(path: str) -> None:
     old_version = "0.1"
     new_version = "0.2"
 
+    path = str(path)
     _check_version(path, old_version, new_version)
-    backup_path = _backup_file(path)
+    backup_path = _backup_file(path, revision)
+    # TODO: Support locking
     with TinyDB(backup_path) as old_db:
         old_commits = old_db.all()
         old_temp = old_db.table(TEMP_TABLE).get(doc_id=TEMP_DOC_ID)
@@ -655,11 +700,10 @@ def migrate_param_store_0_1_to_0_2(path: str) -> None:
             _wrap_params(new_temp)
             _rename_ns(new_temp)
             new_db.table(TEMP_TABLE).insert(new_temp)
-        _set_version(new_db, new_version)
 
 
-def _backup_file(path):
-    backup_path = path.replace(".json", ".bak.json")
+def _backup_file(path: str, revision: str):
+    backup_path = f"{path}.{revision}.bak"
     shutil.move(path, backup_path)
     return backup_path
 
@@ -670,7 +714,6 @@ def _wrap_params(new_commit):
         value = params[key]
         if not isinstance(value, Param):
             params[key] = Param(value)
-    # _map_dict_in_place(lambda val: Param(val), new_doc["params"])
     new_commit["params"] = params
 
 
@@ -680,13 +723,17 @@ def _rename_ns(new_commit):
     new_commit["metadata"]["timestamp"] = timestamp
 
 
-def _set_version(db: TinyDB, version: str):
+def _set_version(db: TinyDB | str, version: str, revision: Optional[str] = ""):
+    if isinstance(db, str):
+        # TODO: Support locking
+        db = TinyDB(db, storage=JSONPickleStorage)
     info_table = db.table(INFO_TABLE)
     info_doc = info_table.get(doc_id=INFO_DOC_ID)
     if info_doc:
         info_doc[VERSION_KEY] = version
+        info_doc[REVISION_KEY] = revision
     else:
-        info_table.insert(dict(VERSION_KEY=version))
+        info_table.insert(dict(VERSION_KEY=version, REVISION_KEY=revision))
 
 
 def _get_version(db: TinyDB):
